
C      __________________________________________________________________


       PROGRAM PVNSLM
C      ______________


C      Main routine for controlling the Primitive Variable, Non-Staggered,
C      LaMinar fluid flow model using the Finite Analytic method.


C      Update 05.04.99                            Author :: R.A. Bernatz
C      __________________________________________________________________

         
      INCLUDE 'common.f'

      OPEN(UNIT=40,FILE='systke.txt',STATUS='UNKNOWN')
      OPEN(UNIT=50,FILE='runhis.txt',STATUS='UNKNOWN')

      CALL SETPRM 
      CALL CHKPRM
      CALL GRIDGN
      CALL SETINC
      CALL UFLBNC
      CALL WFLBNC
      CALL PFLBNC
      CALL TFLBNC       
      
      WRITE(*,100) ILTS-IFTS+1,ILTS

      DO 1000 ITS= IFTS,ILTS

        ID1 = MOD(ITS+3,4) + 1
        CALL COEF01

C      ------------------------------------------------------------
C      Calculate New U,W,P, and T Fields
C      ------------------------------------------------------------

        DO 2000 ITIN=1,MNIT
          WRITE(*,101)ITS,ITIN
          ID2 = MOD(ITIN+1,2)+1  

          CALL CLCSRC(1)
          CALL TIMINT(1,UFLM,UFLP,FTUFL)
          CALL CLCUEP

          CALL CLCSRC(2)
          CALL TIMINT(2,WFLM,WFLP,FTWFL)
          CALL CLCWNP

C         -----------------------------------
C         Correct the Pressure and Velocity
C         -----------------------------------

          CALL CLCDIL(IXPD,IZPD)
          CALL PRSCOR
          CALL UWCRTN

          CALL CLCSRC(4)
          CALL TIMINT(4,TFLM,TFLP,FTTFL)

C         --------------------------------------------
C         CHECK FOR CONVERGENCE IN THIS TIME STEP
C         --------------------------------------------

          CALL CHKCNV(UFLP,UFLC,TTUFL,UN,UO,ERU,PERU,IXPU,IZPU,IEU)
          CALL CHKCNV(WFLP,WFLC,TTWFL,WN,WO,ERW,PERW,IXPW,IZPW,IEW)
          CALL CHKCNV(PFLP,PFLC,TTPFL,PN,PO,ERP,PERP,IXPP,IZPP,IEP)
          CALL CHKCNV(TFLP,TFLC,TTTFL,TN,TO,ERT,PERT,IXPT,IZPT,IET)

          ICV2(ID2)=1
          IF( (IEU+IEW+IEP+IET).EQ.0 ) ICV2(ID2)=0
          ICVSUM2 = ICV2(1)+ICV2(2)
          IF( ICVSUM2.EQ.0) GO TO 1

2000    CONTINUE

C       -------------------------------
C       Check for steady state solution
C       -------------------------------  
        
1       CALL CHKCNV(UFLP,UFLM,TTUFL,UN,UO,ERU,PERU,IXPU,IZPU,IEU) 
        CALL CHKCNV(WFLP,WFLM,TTWFL,WN,WO,ERW,PERW,IXPW,IZPW,IEW)
        CALL CHKCNV(PFLP,PFLM,TTPFL,PN,PO,ERP,PERP,IXPP,IZPP,IEP)
        CALL CHKCNV(TFLP,TFLM,TTTFL,TN,TO,ERT,PERT,IXPT,IZPT,IET)
        ICV1(ID1)=1 
        IF( (IEU+IEW+IEP+IET).EQ.0 ) ICV1(ID1)=0
        ICVSUM1 = ICV1(1)+ICV1(2)+ICV1(3)+ICV1(4)
        CALL UFLBNC
        CALL WFLBNC
        CALL PFLBNC
        CALL TFLBNC 
        CALL CLCTKE(TOTKE)
        IF (ITS.EQ.ILTS) THEN 
          WRITE(40,301)ITS*TAU,TOTKE       
        ELSE
          WRITE(40,300)ITS*TAU,TOTKE 
        END IF         
        IF(ICVSUM1.EQ.0) GO TO 2
        CALL UPDATE 
        
        WRITE(50,200)ITS
        WRITE(50,201)
        WRITE(50,202)
        WRITE(50,203)UN,UO,ERU,PERU,IXPU,IZPU,IEU
        WRITE(50,204)WN,WO,ERW,PERW,IXPW,IZPW,IEW
        WRITE(50,205)PN,PO,ERP,PERP,IXPP,IZPP,IEP
        WRITE(50,206)TN,TO,ERT,PERT,IXPT,IZPT,IET
        CALL CLCDIL(IXPD,IZPD)
        WRITE(50,207)DMAX,IXPD,IZPD,DTOTAL 

1000  CONTINUE
      
2     CALL WRTINC
      CALL CLCSTF
      CALL SPYPLT(SFLD,'spystr.txt')
      CALL SPYPLT(TFLP,'spytmp.txt')
      
      CLOSE(40)
      CLOSE(50)

      STOP 
 100  FORMAT(//,2X,'PVNSLM is executing a total of',I5,
     &       ' time steps. Last time step is ',I6,///)
 101  FORMAT('+',2X,'Time Step :: ',I4,5X,'Time Iteration :: ',I2) 
 
 200  FORMAT(/,10X,'Convergence history for time step ',I4,/)
 201  FORMAT(2X,'Field',2X,'  New Val ',2X,'  Old Val ',2X,' Max Diff ',
     &      2X,' Pct Diff ',2X,'x Cord',2X,'z Cord',2X,'Code')
 202  FORMAT(2X,'-----',2X,'  ------- ',2X,'  ------- ',2X,' -------- ',
     &      2X,' -------- ',2X,'- ----',2X,'- ----',2X,'----',/)
 203  FORMAT(2X,'  U  ',3(2X,D10.4),2X,F10.4,3X,I3,5X,I3,5X,I1)
 204  FORMAT(2X,'  W  ',3(2X,D10.4),2X,F10.4,3X,I3,5X,I3,5X,I1)
 205  FORMAT(2X,'  P  ',3(2X,D10.4),2X,F10.4,3X,I3,5X,I3,5X,I1)
 206  FORMAT(2X,'  T  ',3(2X,D10.4),2X,F10.4,3X,I3,5X,I3,5X,I1)
 207  FORMAT(/,2X,'D  Err',4X,'maximum : ',2X,D10.4,4X,I3,4X,I3,6X,
     &       'total :',2X,D10.4)  
     
 300  FORMAT(2X,'[',F9.4,',',F19.14,'],')
 301  FORMAT(2X,'[',F9.4,',',F19.14,']:')     
      END
      

